import { DefaultPlatform, SQLConnection, SQLConnectionPool, SQLDatabaseAdapter, SQLDatabaseQuery, SQLDatabaseQueryFactory, SQLPersistence, SQLQueryModel, SQLQueryResolver, SQLStatement } from '@deepkit/sql';
import { DatabaseLogger, DatabasePersistenceChangeSet, DatabaseSession, DatabaseTransaction, DeleteResult, Entity, PatchResult } from '@deepkit/orm';
import { PostgresPlatform } from './postgres-platform';
import { Changes, ClassSchema } from '@deepkit/type';
import type { Pool, PoolClient, PoolConfig } from 'pg';
import { ClassType } from '@deepkit/core';
export declare class PostgresStatement extends SQLStatement {
    protected logger: DatabaseLogger;
    protected sql: string;
    protected client: PoolClient;
    protected released: boolean;
    constructor(logger: DatabaseLogger, sql: string, client: PoolClient);
    get(params?: any[]): Promise<any>;
    all(params?: any[]): Promise<any>;
    release(): void;
}
export declare class PostgresConnection extends SQLConnection {
    connection: PoolClient;
    protected changes: number;
    lastReturningRows: any[];
    constructor(connectionPool: PostgresConnectionPool, connection: PoolClient, logger?: DatabaseLogger);
    prepare(sql: string): Promise<PostgresStatement>;
    run(sql: string, params?: any[]): Promise<void>;
    getChanges(): Promise<number>;
}
export declare class PostgresConnectionPool extends SQLConnectionPool {
    protected pool: Pool;
    constructor(pool: Pool);
    getConnection(logger?: DatabaseLogger, transaction?: DatabaseTransaction): Promise<PostgresConnection>;
    release(connection: PostgresConnection): void;
}
export declare class PostgresPersistence extends SQLPersistence {
    protected platform: DefaultPlatform;
    connectionPool: PostgresConnectionPool;
    constructor(platform: DefaultPlatform, connectionPool: PostgresConnectionPool, session: DatabaseSession<any>);
    batchUpdate<T extends Entity>(classSchema: ClassSchema<T>, changeSets: DatabasePersistenceChangeSet<T>[]): Promise<void>;
    protected populateAutoIncrementFields<T>(classSchema: ClassSchema<T>, items: T[]): Promise<void>;
    protected getInsertSQL(classSchema: ClassSchema, fields: string[], values: string[]): string;
    protected placeholderPosition: number;
    protected resetPlaceholderSymbol(): void;
    protected getPlaceholderSymbol(): string;
}
export declare class PostgresSQLQueryResolver<T extends Entity> extends SQLQueryResolver<T> {
    delete(model: SQLQueryModel<T>, deleteResult: DeleteResult<T>): Promise<void>;
    patch(model: SQLQueryModel<T>, changes: Changes<T>, patchResult: PatchResult<T>): Promise<void>;
}
export declare class PostgresSQLDatabaseQuery<T> extends SQLDatabaseQuery<T> {
}
export declare class PostgresSQLDatabaseQueryFactory extends SQLDatabaseQueryFactory {
    createQuery<T extends Entity>(classType: ClassType<T> | ClassSchema<T>): PostgresSQLDatabaseQuery<T>;
}
export declare class PostgresDatabaseAdapter extends SQLDatabaseAdapter {
    protected options: PoolConfig;
    protected pool: Pool;
    connectionPool: PostgresConnectionPool;
    platform: PostgresPlatform;
    constructor(options: PoolConfig);
    getName(): string;
    getSchemaName(): string;
    createPersistence(session: DatabaseSession<this>): SQLPersistence;
    queryFactory(session: DatabaseSession<any>): SQLDatabaseQueryFactory;
    disconnect(force?: boolean): void;
}
